package com.muyu.common.core.enums;

import java.util.Arrays;

import static net.sf.jsqlparser.parser.feature.Feature.values;


/**
 * @Author：weiran
 * @Package：com.muyu.common.core.enums
 * @Project：cloud-common-core
 * @name：SysPayType
 * @Date：2024/8/8 16:55
 */
public enum SysPayType {
    ALI_PAY("aliPay","支付宝"),
    WEICHAT_PAY("weichatPay","微信支付"),
    JD_PAY("jdPay","京东支付");


    private final String code;

    private final String info;

    SysPayType(String code, String info) {
        this.code = code;
        this.info = info;
    }


    public String getCode(){
        return code;
    }

    public String getInfo(){
        return info;
    }


    /**
     * 鉴别Code是否合法
     * 如果存在code则返回true,不存在则返回false
     * @param code
     * @return
     */
    public static boolean isCode(String code){
       return Arrays.stream(values())
               .map(SysPayType::getCode)
               .anyMatch(s->s.equals(code));
    }


    /**
     * 通过code获取支付渠道
     * @param code
     * @return
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(s->s.getCode().equals(code))
                .findFirst()
                .map(SysPayType::getInfo)
                .orElseGet(()->"-");
    }
}
